from setuptools import setup

setup(
    name="gtchecker.com",
    version="0.0.1",
    packages=["gtchecker"],
    url="https://gtchecker.com",
    license="MIT",
    author="Joker",
    author_email="abuse@gtchecker.com",
    description="Official API Wrapper for Gtchecker.com",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent"
    ]
)